# coding: utf-8

# flake8: noqa

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# import apis into sdk package
from haplohub.api.api_key_api import ApiKeyApi
from haplohub.api.biomarker_api import BiomarkerApi
from haplohub.api.cohort_api import CohortApi
from haplohub.api.environment_api import EnvironmentApi
from haplohub.api.file_api import FileApi
from haplohub.api.log_api import LogApi
from haplohub.api.member_api import MemberApi
from haplohub.api.member_report_api import MemberReportApi
from haplohub.api.metadata_api import MetadataApi
from haplohub.api.model_api import ModelApi
from haplohub.api.prediction_api import PredictionApi
from haplohub.api.report_template_api import ReportTemplateApi
from haplohub.api.sample_api import SampleApi
from haplohub.api.upload_api import UploadApi
from haplohub.api.variant_api import VariantApi
from haplohub.api.workflow_api import WorkflowApi
from haplohub.api.default_api import DefaultApi

# import ApiClient
from haplohub.api_response import ApiResponse
from haplohub.api_client import ApiClient
from haplohub.configuration import Configuration
from haplohub.exceptions import OpenApiException
from haplohub.exceptions import ApiTypeError
from haplohub.exceptions import ApiValueError
from haplohub.exceptions import ApiKeyError
from haplohub.exceptions import ApiAttributeError
from haplohub.exceptions import ApiException

# import models into sdk package
from haplohub.models.accession_schema import AccessionSchema
from haplohub.models.api_key_schema import ApiKeySchema
from haplohub.models.auth_schema import AuthSchema
from haplohub.models.biomarker_result_schema import BiomarkerResultSchema
from haplohub.models.cohort_detail_schema import CohortDetailSchema
from haplohub.models.cohort_schema import CohortSchema
from haplohub.models.create_api_key_schema import CreateApiKeySchema
from haplohub.models.create_cohort_request import CreateCohortRequest
from haplohub.models.create_cohort_response import CreateCohortResponse
from haplohub.models.create_environment_request import CreateEnvironmentRequest
from haplohub.models.create_environment_response import CreateEnvironmentResponse
from haplohub.models.create_member_request import CreateMemberRequest
from haplohub.models.create_model_request import CreateModelRequest
from haplohub.models.create_model_response import CreateModelResponse
from haplohub.models.create_report_template_request import CreateReportTemplateRequest
from haplohub.models.create_report_template_response import CreateReportTemplateResponse
from haplohub.models.create_sample_request import CreateSampleRequest
from haplohub.models.create_upload_request_request import CreateUploadRequestRequest
from haplohub.models.detail_workflow_run_schema import DetailWorkflowRunSchema
from haplohub.models.dir_schema import DirSchema
from haplohub.models.download_link_schema import DownloadLinkSchema
from haplohub.models.environment_schema import EnvironmentSchema
from haplohub.models.error_response import ErrorResponse
from haplohub.models.error_schema import ErrorSchema
from haplohub.models.file_dir_schema import FileDirSchema
from haplohub.models.file_info import FileInfo
from haplohub.models.file_schema import FileSchema
from haplohub.models.generic_response import GenericResponse
from haplohub.models.get_cohort_response import GetCohortResponse
from haplohub.models.get_hgvs_response import GetHgvsResponse
from haplohub.models.get_prediction_response import GetPredictionResponse
from haplohub.models.get_prediction_results_response import GetPredictionResultsResponse
from haplohub.models.get_report_template_response import GetReportTemplateResponse
from haplohub.models.get_variant_request import GetVariantRequest
from haplohub.models.hgvs_dosage_schema import HgvsDosageSchema
from haplohub.models.hgvs_schema import HgvsSchema
from haplohub.models.infinity_paginated_response_log_schema import InfinityPaginatedResponseLogSchema
from haplohub.models.list_files_filter import ListFilesFilter
from haplohub.models.log_schema import LogSchema
from haplohub.models.lookup_hgvs_request import LookupHgvsRequest
from haplohub.models.ml_model_schema import MLModelSchema
from haplohub.models.member_schema import MemberSchema
from haplohub.models.model_id import ModelId
from haplohub.models.order_schema import OrderSchema
from haplohub.models.paginated_response_accession_schema import PaginatedResponseAccessionSchema
from haplohub.models.paginated_response_api_key_schema import PaginatedResponseApiKeySchema
from haplohub.models.paginated_response_cohort_schema import PaginatedResponseCohortSchema
from haplohub.models.paginated_response_environment_schema import PaginatedResponseEnvironmentSchema
from haplohub.models.paginated_response_ml_model_schema import PaginatedResponseMLModelSchema
from haplohub.models.paginated_response_member_schema import PaginatedResponseMemberSchema
from haplohub.models.paginated_response_prediction_schema import PaginatedResponsePredictionSchema
from haplohub.models.paginated_response_report_template_schema import PaginatedResponseReportTemplateSchema
from haplohub.models.paginated_response_sample_schema import PaginatedResponseSampleSchema
from haplohub.models.paginated_response_workflow_run_schema import PaginatedResponseWorkflowRunSchema
from haplohub.models.prediction_results_schema import PredictionResultsSchema
from haplohub.models.prediction_schema import PredictionSchema
from haplohub.models.prediction_status import PredictionStatus
from haplohub.models.push_credentials import PushCredentials
from haplohub.models.push_model_request import PushModelRequest
from haplohub.models.report_template_schema import ReportTemplateSchema
from haplohub.models.report_type import ReportType
from haplohub.models.request_schema import RequestSchema
from haplohub.models.response import Response
from haplohub.models.response_schema import ResponseSchema
from haplohub.models.response_status import ResponseStatus
from haplohub.models.result_list_response_biomarker_result_schema import ResultListResponseBiomarkerResultSchema
from haplohub.models.result_list_response_hgvs_schema import ResultListResponseHgvsSchema
from haplohub.models.result_list_response_variant_schema import ResultListResponseVariantSchema
from haplohub.models.result_response import ResultResponse
from haplohub.models.result_response_api_key_schema import ResultResponseApiKeySchema
from haplohub.models.result_response_detail_workflow_run_schema import ResultResponseDetailWorkflowRunSchema
from haplohub.models.result_response_download_link_schema import ResultResponseDownloadLinkSchema
from haplohub.models.result_response_file_dir_schema import ResultResponseFileDirSchema
from haplohub.models.result_response_file_schema import ResultResponseFileSchema
from haplohub.models.result_response_member_schema import ResultResponseMemberSchema
from haplohub.models.result_response_push_credentials import ResultResponsePushCredentials
from haplohub.models.result_response_sample_schema import ResultResponseSampleSchema
from haplohub.models.result_response_upload_request_response import ResultResponseUploadRequestResponse
from haplohub.models.result_schema import ResultSchema
from haplohub.models.run_prediction_request import RunPredictionRequest
from haplohub.models.run_prediction_response import RunPredictionResponse
from haplohub.models.sample_schema import SampleSchema
from haplohub.models.success_response import SuccessResponse
from haplohub.models.switch_environment_response import SwitchEnvironmentResponse
from haplohub.models.tenant_schema import TenantSchema
from haplohub.models.update_cohort_request import UpdateCohortRequest
from haplohub.models.update_cohort_response import UpdateCohortResponse
from haplohub.models.update_member_request import UpdateMemberRequest
from haplohub.models.update_report_template_request import UpdateReportTemplateRequest
from haplohub.models.update_report_template_response import UpdateReportTemplateResponse
from haplohub.models.update_sample_request import UpdateSampleRequest
from haplohub.models.upload_link import UploadLink
from haplohub.models.upload_request_response import UploadRequestResponse
from haplohub.models.upload_type import UploadType
from haplohub.models.user_schema import UserSchema
from haplohub.models.variant_range import VariantRange
from haplohub.models.variant_schema import VariantSchema
from haplohub.models.workflow_history_schema import WorkflowHistorySchema
from haplohub.models.workflow_run_schema import WorkflowRunSchema



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.cohort_detail_schema import CohortDetailSchema  # noqa: E501


class TestCohortDetailSchema(unittest.TestCase):
    """CohortDetailSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CohortDetailSchema:
        """Test CohortDetailSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CohortDetailSchema`
        """
        model = CohortDetailSchema()  # noqa: E501
        if include_optional:
            return CohortDetailSchema(
                id = 56,
                name = '',
                slug = '',
                description = '',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sample_files = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return CohortDetailSchema(
                name = '',
                slug = '',
                description = '',
                sample_files = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testCohortDetailSchema(self):
        """Test CohortDetailSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest


class TestReportType(unittest.TestCase):
    """ReportType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportType(self):
        """Test ReportType"""
        # inst = ReportType()


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import date, datetime
from typing import Optional

from pydantic import BaseModel, StrictInt, constr


class MemberSchema(BaseModel):
    """
    MemberSchema
    """

    id: Optional[StrictInt] = None
    patient_id: Optional[constr(strict=True, max_length=255)] = None
    first_name: Optional[constr(strict=True, max_length=255)] = None
    last_name: Optional[constr(strict=True, max_length=255)] = None
    gender: Optional[constr(strict=True, max_length=50)] = None
    birth_date: Optional[date] = None
    created: Optional[datetime] = None
    __properties = ["id", "patient_id", "first_name", "last_name", "gender", "birth_date", "created"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MemberSchema:
        """Create an instance of MemberSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict["id"] = None

        # set to None if patient_id (nullable) is None
        # and __fields_set__ contains the field
        if self.patient_id is None and "patient_id" in self.__fields_set__:
            _dict["patient_id"] = None

        # set to None if first_name (nullable) is None
        # and __fields_set__ contains the field
        if self.first_name is None and "first_name" in self.__fields_set__:
            _dict["first_name"] = None

        # set to None if last_name (nullable) is None
        # and __fields_set__ contains the field
        if self.last_name is None and "last_name" in self.__fields_set__:
            _dict["last_name"] = None

        # set to None if gender (nullable) is None
        # and __fields_set__ contains the field
        if self.gender is None and "gender" in self.__fields_set__:
            _dict["gender"] = None

        # set to None if birth_date (nullable) is None
        # and __fields_set__ contains the field
        if self.birth_date is None and "birth_date" in self.__fields_set__:
            _dict["birth_date"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MemberSchema:
        """Create an instance of MemberSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MemberSchema.parse_obj(obj)

        _obj = MemberSchema.parse_obj(
            {
                "id": obj.get("id"),
                "patient_id": obj.get("patient_id"),
                "first_name": obj.get("first_name"),
                "last_name": obj.get("last_name"),
                "gender": obj.get("gender"),
                "birth_date": obj.get("birth_date"),
                "created": obj.get("created"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, constr


class CohortSchema(BaseModel):
    """
    CohortSchema
    """

    id: Optional[StrictInt] = None
    name: constr(strict=True, max_length=255) = Field(...)
    read_only: Optional[StrictBool] = False
    description: StrictStr = Field(...)
    created: Optional[datetime] = None
    modified: Optional[datetime] = None
    __properties = ["id", "name", "read_only", "description", "created", "modified"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CohortSchema:
        """Create an instance of CohortSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict["id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CohortSchema:
        """Create an instance of CohortSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CohortSchema.parse_obj(obj)

        _obj = CohortSchema.parse_obj(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "read_only": obj.get("read_only") if obj.get("read_only") is not None else False,
                "description": obj.get("description"),
                "created": obj.get("created"),
                "modified": obj.get("modified"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

try:
    from ._version import __version__
except ImportError:
    __version__ = "0.0.0+unknown"

# import models into model package
from haplohub.models.accession_schema import AccessionSchema
from haplohub.models.api_key_schema import ApiKeySchema
from haplohub.models.auth_schema import AuthSchema
from haplohub.models.biomarker_result_schema import BiomarkerResultSchema
from haplohub.models.cohort_detail_schema import CohortDetailSchema
from haplohub.models.cohort_schema import CohortSchema
from haplohub.models.create_api_key_schema import CreateApiKeySchema
from haplohub.models.create_cohort_request import CreateCohortRequest
from haplohub.models.create_cohort_response import CreateCohortResponse
from haplohub.models.create_environment_request import CreateEnvironmentRequest
from haplohub.models.create_environment_response import CreateEnvironmentResponse
from haplohub.models.create_member_request import CreateMemberRequest
from haplohub.models.create_model_request import CreateModelRequest
from haplohub.models.create_model_response import CreateModelResponse
from haplohub.models.create_report_template_request import CreateReportTemplateRequest
from haplohub.models.create_report_template_response import CreateReportTemplateResponse
from haplohub.models.create_sample_request import CreateSampleRequest
from haplohub.models.create_upload_request_request import CreateUploadRequestRequest
from haplohub.models.detail_workflow_run_schema import DetailWorkflowRunSchema
from haplohub.models.dir_schema import DirSchema
from haplohub.models.download_link_schema import DownloadLinkSchema
from haplohub.models.environment_schema import EnvironmentSchema
from haplohub.models.error_response import ErrorResponse
from haplohub.models.error_schema import ErrorSchema
from haplohub.models.file_dir_schema import FileDirSchema
from haplohub.models.file_info import FileInfo
from haplohub.models.file_schema import FileSchema
from haplohub.models.generic_response import GenericResponse
from haplohub.models.get_cohort_response import GetCohortResponse
from haplohub.models.get_hgvs_response import GetHgvsResponse
from haplohub.models.get_prediction_response import GetPredictionResponse
from haplohub.models.get_prediction_results_response import GetPredictionResultsResponse
from haplohub.models.get_report_template_response import GetReportTemplateResponse
from haplohub.models.get_variant_request import GetVariantRequest
from haplohub.models.hgvs_dosage_schema import HgvsDosageSchema
from haplohub.models.hgvs_schema import HgvsSchema
from haplohub.models.infinity_paginated_response_log_schema import InfinityPaginatedResponseLogSchema
from haplohub.models.list_files_filter import ListFilesFilter
from haplohub.models.log_schema import LogSchema
from haplohub.models.lookup_hgvs_request import LookupHgvsRequest
from haplohub.models.ml_model_schema import MLModelSchema
from haplohub.models.member_schema import MemberSchema
from haplohub.models.model_id import ModelId
from haplohub.models.order_schema import OrderSchema
from haplohub.models.paginated_response_accession_schema import PaginatedResponseAccessionSchema
from haplohub.models.paginated_response_api_key_schema import PaginatedResponseApiKeySchema
from haplohub.models.paginated_response_cohort_schema import PaginatedResponseCohortSchema
from haplohub.models.paginated_response_environment_schema import PaginatedResponseEnvironmentSchema
from haplohub.models.paginated_response_ml_model_schema import PaginatedResponseMLModelSchema
from haplohub.models.paginated_response_member_schema import PaginatedResponseMemberSchema
from haplohub.models.paginated_response_prediction_schema import PaginatedResponsePredictionSchema
from haplohub.models.paginated_response_report_template_schema import PaginatedResponseReportTemplateSchema
from haplohub.models.paginated_response_sample_schema import PaginatedResponseSampleSchema
from haplohub.models.paginated_response_workflow_run_schema import PaginatedResponseWorkflowRunSchema
from haplohub.models.prediction_results_schema import PredictionResultsSchema
from haplohub.models.prediction_schema import PredictionSchema
from haplohub.models.prediction_status import PredictionStatus
from haplohub.models.push_credentials import PushCredentials
from haplohub.models.push_model_request import PushModelRequest
from haplohub.models.report_template_schema import ReportTemplateSchema
from haplohub.models.report_type import ReportType
from haplohub.models.request_schema import RequestSchema
from haplohub.models.response import Response
from haplohub.models.response_schema import ResponseSchema
from haplohub.models.response_status import ResponseStatus
from haplohub.models.result_list_response_biomarker_result_schema import ResultListResponseBiomarkerResultSchema
from haplohub.models.result_list_response_hgvs_schema import ResultListResponseHgvsSchema
from haplohub.models.result_list_response_variant_schema import ResultListResponseVariantSchema
from haplohub.models.result_response import ResultResponse
from haplohub.models.result_response_api_key_schema import ResultResponseApiKeySchema
from haplohub.models.result_response_detail_workflow_run_schema import ResultResponseDetailWorkflowRunSchema
from haplohub.models.result_response_download_link_schema import ResultResponseDownloadLinkSchema
from haplohub.models.result_response_file_dir_schema import ResultResponseFileDirSchema
from haplohub.models.result_response_file_schema import ResultResponseFileSchema
from haplohub.models.result_response_member_schema import ResultResponseMemberSchema
from haplohub.models.result_response_push_credentials import ResultResponsePushCredentials
from haplohub.models.result_response_sample_schema import ResultResponseSampleSchema
from haplohub.models.result_response_upload_request_response import ResultResponseUploadRequestResponse
from haplohub.models.result_schema import ResultSchema
from haplohub.models.run_prediction_request import RunPredictionRequest
from haplohub.models.run_prediction_response import RunPredictionResponse
from haplohub.models.sample_schema import SampleSchema
from haplohub.models.success_response import SuccessResponse
from haplohub.models.switch_environment_response import SwitchEnvironmentResponse
from haplohub.models.tenant_schema import TenantSchema
from haplohub.models.update_cohort_request import UpdateCohortRequest
from haplohub.models.update_cohort_response import UpdateCohortResponse
from haplohub.models.update_member_request import UpdateMemberRequest
from haplohub.models.update_report_template_request import UpdateReportTemplateRequest
from haplohub.models.update_report_template_response import UpdateReportTemplateResponse
from haplohub.models.update_sample_request import UpdateSampleRequest
from haplohub.models.upload_link import UploadLink
from haplohub.models.upload_request_response import UploadRequestResponse
from haplohub.models.upload_type import UploadType
from haplohub.models.user_schema import UserSchema
from haplohub.models.variant_range import VariantRange
from haplohub.models.variant_schema import VariantSchema
from haplohub.models.workflow_history_schema import WorkflowHistorySchema
from haplohub.models.workflow_run_schema import WorkflowRunSchema



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.workflow_run_schema import WorkflowRunSchema  # noqa: E501


class TestWorkflowRunSchema(unittest.TestCase):
    """WorkflowRunSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkflowRunSchema:
        """Test WorkflowRunSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `WorkflowRunSchema`
        """
        model = WorkflowRunSchema()  # noqa: E501
        if include_optional:
            return WorkflowRunSchema(
                triggered_by = haplohub.models.user_schema.UserSchema(
                    id = '', ),
                id = 56,
                workflow_id = '',
                workflow_type = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return WorkflowRunSchema(
                workflow_id = '',
                workflow_type = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testWorkflowRunSchema(self):
        """Test WorkflowRunSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, conlist

from haplohub.models.file_info import FileInfo
from haplohub.models.upload_type import UploadType


class CreateUploadRequestRequest(BaseModel):
    """
    CreateUploadRequestRequest
    """

    upload_request_id: StrictStr = Field(...)
    files: conlist(FileInfo) = Field(...)
    file_type: UploadType = Field(...)
    sample_id: Optional[StrictStr] = None
    member_id: Optional[StrictStr] = None
    __properties = ["upload_request_id", "files", "file_type", "sample_id", "member_id"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateUploadRequestRequest:
        """Create an instance of CreateUploadRequestRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item in self.files:
                if _item:
                    _items.append(_item.to_dict())
            _dict["files"] = _items
        # set to None if sample_id (nullable) is None
        # and __fields_set__ contains the field
        if self.sample_id is None and "sample_id" in self.__fields_set__:
            _dict["sample_id"] = None

        # set to None if member_id (nullable) is None
        # and __fields_set__ contains the field
        if self.member_id is None and "member_id" in self.__fields_set__:
            _dict["member_id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateUploadRequestRequest:
        """Create an instance of CreateUploadRequestRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateUploadRequestRequest.parse_obj(obj)

        _obj = CreateUploadRequestRequest.parse_obj(
            {
                "upload_request_id": obj.get("upload_request_id"),
                "files": [FileInfo.from_dict(_item) for _item in obj.get("files")] if obj.get("files") is not None else None,
                "file_type": obj.get("file_type"),
                "sample_id": obj.get("sample_id"),
                "member_id": obj.get("member_id"),
            }
        )
        return _obj



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.create_report_template_request import CreateReportTemplateRequest  # noqa: E501


class TestCreateReportTemplateRequest(unittest.TestCase):
    """CreateReportTemplateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateReportTemplateRequest:
        """Test CreateReportTemplateRequest
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateReportTemplateRequest`
        """
        model = CreateReportTemplateRequest()  # noqa: E501
        if include_optional:
            return CreateReportTemplateRequest(
                name = '',
                report_type = 'text'
            )
        else:
            return CreateReportTemplateRequest(
                name = '',
                report_type = 'text',
        )
        """

    def testCreateReportTemplateRequest(self):
        """Test CreateReportTemplateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.prediction_api import PredictionApi  # noqa: E501


class TestPredictionApi(unittest.TestCase):
    """PredictionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PredictionApi()

    def tearDown(self) -> None:
        pass

    def test_get_prediction(self) -> None:
        """Test case for get_prediction

        Get prediction  # noqa: E501
        """
        pass

    def test_get_prediction_results(self) -> None:
        """Test case for get_prediction_results

        Get prediction results  # noqa: E501
        """
        pass

    def test_list_predictions(self) -> None:
        """Test case for list_predictions

        List predictions  # noqa: E501
        """
        pass

    def test_run_prediction(self) -> None:
        """Test case for run_prediction

        Run prediction  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, StrictStr


class UpdateReportTemplateRequest(BaseModel):
    """
    UpdateReportTemplateRequest
    """

    name: Optional[StrictStr] = None
    report_type: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    template: Optional[StrictStr] = None
    __properties = ["name", "report_type", "description", "template"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateReportTemplateRequest:
        """Create an instance of UpdateReportTemplateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict["name"] = None

        # set to None if report_type (nullable) is None
        # and __fields_set__ contains the field
        if self.report_type is None and "report_type" in self.__fields_set__:
            _dict["report_type"] = None

        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        # set to None if template (nullable) is None
        # and __fields_set__ contains the field
        if self.template is None and "template" in self.__fields_set__:
            _dict["template"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateReportTemplateRequest:
        """Create an instance of UpdateReportTemplateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateReportTemplateRequest.parse_obj(obj)

        _obj = UpdateReportTemplateRequest.parse_obj(
            {
                "name": obj.get("name"),
                "report_type": obj.get("report_type"),
                "description": obj.get("description"),
                "template": obj.get("template"),
            }
        )
        return _obj



# flake8: noqa

# import apis into api package
from haplohub.api.api_key_api import ApiKeyApi
from haplohub.api.biomarker_api import BiomarkerApi
from haplohub.api.cohort_api import CohortApi
from haplohub.api.environment_api import EnvironmentApi
from haplohub.api.file_api import FileApi
from haplohub.api.log_api import LogApi
from haplohub.api.member_api import MemberApi
from haplohub.api.member_report_api import MemberReportApi
from haplohub.api.metadata_api import MetadataApi
from haplohub.api.model_api import ModelApi
from haplohub.api.prediction_api import PredictionApi
from haplohub.api.report_template_api import ReportTemplateApi
from haplohub.api.sample_api import SampleApi
from haplohub.api.upload_api import UploadApi
from haplohub.api.variant_api import VariantApi
from haplohub.api.workflow_api import WorkflowApi
from haplohub.api.default_api import DefaultApi
